@@ -55,7 +55,7 @@ class Module:
     def fit(self,
             x: np.ndarray,
             y: np.ndarray,
-            batch_size: int = 64,
+            batch_size: int = None,
             epochs: int = 1,
             verbose: int = 1,
             shuffle: bool = True,
@@ -64,6 +64,8 @@ class Module:
             initial_epoch: int = 0,
             ) -> dict:
 
+        x = np.asarray(x)
+        y = np.asarray(y)
         if validation_data is None and 0. < validation_split < 1.:
             split = int(x.shape[0] * validation_split)
             valid_x, valid_y = x[-split:], y[-split:]
@@ -168,7 +170,7 @@ class Module:
 
         return pred
 
-    def forward(self, x, *args):
+    def forward(self, x):
         raise NotImplemented
 
     def backward(self, loss: Variable):
@@ -193,22 +195,13 @@ class Module:
         self.loss = loss
 
     def __str__(self):
-        bar_nums = 120
+        bar_nums = 75
         print('*' * bar_nums)
-
-        print('Layer(type)'.ljust(40), 'Output Shape'.ljust(40), 'Param'.ljust(12), 'Connected to'.ljust(15))
+        print('Layer(type)'.ljust(25), 'Output Shape'.ljust(20), 'Param'.ljust(10), 'Connected to'.ljust(15))
         print('#' * bar_nums)
         total_params = 0
-        name_dict = {}
         for layer in self.graph:
-            if layer.name is None:
-                if layer.__class__.__name__ not in name_dict.keys():
-                    name_dict[layer.__class__.__name__] = -1
-                name_dict[layer.__class__.__name__] += 1
-                layer.name = layer.__class__.__name__.lower() + str(name_dict[layer.__class__.__name__])
-
             layer_name = '%s (%s)' % (layer.name, layer.__class__.__name__)
-
             params = layer.params_count()
             total_params += params
             first = True
@@ -219,14 +212,14 @@ class Module:
                     else:
                         connected = prev_layer.__class__.__name__
                     if first:
-                        print(layer_name.ljust(40), str((None,) + layer.shape).ljust(40), str(params).ljust(12),
+                        print(layer_name.ljust(25), str((None,) + layer.shape).ljust(20), str(params).ljust(10),
                               connected.ljust(15))
                         first = False
                     else:
-                        print(''.ljust(40), ''.ljust(40), ''.ljust(12), connected.ljust(15))
+                        print(''.ljust(25), ''.ljust(20), ''.ljust(10), connected.ljust(15))
             else:
                 connected = '\n'
-                print(layer_name.ljust(40), str((None,) + layer.shape).ljust(40), str(params).ljust(12),
+                print(layer_name.ljust(25), str((None,) + layer.shape).ljust(20), str(params).ljust(10),
                       connected.ljust(15))
             print('-' * bar_nums)
 
@@ -248,7 +241,7 @@ class Sequential(Module):
     def add(self, layer):
         self.graph.append(layer)
 
-    def compile(self, optimizer, loss):
+    def compile(self, optimizer, loss, **kwargs):
         assert self.graph
         next_layer = None
         for layer in self.graph:
@@ -259,10 +252,10 @@ class Sequential(Module):
                 if v is not None and v.requires_grad and v not in self.trainable_variables:
                     self.trainable_variables.append(v)
         self.loss = get_objective(loss)
-        self.optimizer = get_optimizer(optimizer)
+        self.optimizer = get_optimizer(optimizer, **kwargs)
         self.optimizer.trainable_variables = self.trainable_variables
 
-    def forward(self, x, *args):
+    def forward(self, x):
         for layer in self.graph:
             if hasattr(layer, 'variables') and len(layer.variables) == 0:
                 layer.initial_params(x.shape[1:])
@@ -305,7 +298,7 @@ class Model(Module):
         self.optimizer = get_optimizer(optimizer, **kwargs)
         self.optimizer.trainable_variables = self.trainable_variables
 
-    def forward(self, x: Variable, *args):
+    def forward(self, x: Variable):
         self.inputs.input_data = x
         outputs = None
         for layer in self.graph:
